@@ -26,6 +26,7 @@ class Remote_operation():
     def exec_remote_shell(self,cmd):
         '''
         ssh 登录到指定 ip 上,执行命令然后返回执行结果
+
         :param cmd:
         :param ip:
         :param port:
@@ -41,6 +42,8 @@ class Remote_operation():
 
     def ssh_scp_put(self,local_file,remote_file):
         """
+        通过ssh上传本地文件到远程服务器
+
         :param local_file:
         :param remote_file:
         :return:
@@ -55,6 +58,11 @@ class Remote_operation():
         sftp.put(local_file, remote_file)
 
     def ssh_scp_get(self,local_file, remote_file):
+        """
+        把本地文件上传到远程服务器
+
+        """
+
         ssh = paramiko.SSHClient()
         ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
         ssh.connect(self.ip, self.port, self.username, self.password)
@@ -125,28 +133,27 @@ class MockServerClass:
 
     """
 
-    def __init__(self,mock_server_port,mock_server_log_path="request_data.txt",remote_mock_server_machine=None):
+    def __init__(self,mock_server_port,remote_mock_server_machine=None):
         """
         :param mock_server_machine:     模拟服务器的登录信息   字典类型 如 {"ip":"192.168.3.67","port":"22","username":"root","password":"jiexijiexi@@"}
         :param mock_server_port:        模拟 服务器的监听端口号， 整形
         """
-        self.route_code_list = []
-        self.remote_mock_server_machine = remote_mock_server_machine
-        self.mock_server_port = mock_server_port
-        self.mock_server_log_path = mock_server_log_path
+        self.__route_code_list = []
+        self.__remote_mock_server_machine = remote_mock_server_machine
+        self.__mock_server_port = mock_server_port
 
-        if self.remote_mock_server_machine == None:
+        if self.__remote_mock_server_machine == None:
             if platform.system() == "Windows":
-                self.system_operation = WindoxLocalOperation()
+                self.__system_operation = WindoxLocalOperation()
             elif platform.system() == "Linux":
-                self.system_operation = LinuxLocalOperation()
+                self.__system_operation = LinuxLocalOperation()
         else:
             self.system_operation = LinuxRemoteOperation(remote_mock_server_machine)
 
         mock_server_listen_port = mock_server_port
-        mock_server_ip = self.remote_mock_server_machine["ip"] if self.remote_mock_server_machine else "127.0.0.1"
-        self.query_request_data_interface_url = f"http://{mock_server_ip}:{mock_server_listen_port}/get_mock_server_all_request_data"
-        self.clear_request_data_interface_url = f"http://{mock_server_ip}:{mock_server_listen_port}/clear_mock_server_request_data"
+        mock_server_ip = self.__remote_mock_server_machine["ip"] if self.__remote_mock_server_machine else "127.0.0.1"
+        self.__query_request_data_interface_url = f"http://{mock_server_ip}:{mock_server_listen_port}/get_mock_server_all_request_data"
+        self.__clear_request_data_interface_url = f"http://{mock_server_ip}:{mock_server_listen_port}/clear_mock_server_request_data"
 
     def add_route(self,route_path,response_date="{}",response_status='200',response_headers='{}',processing_time = '0'):
         """
@@ -160,7 +167,7 @@ class MockServerClass:
 
         route_path = route_path.replace("mock_other_path","<path:path>")
         get_request_data_code= '{"request_url": request_url, "request_method": request_method, "request_body": request_body,"request_headers": request_headers}'
-        route_code_list_len = len(self.route_code_list)
+        route_code_list_len = len(self.__route_code_list)
 
         route_code = f"""@app.route('{route_path}',methods=["POST","GET","PURGE"])
 def processing_requests_{route_code_list_len}(**args):
@@ -186,11 +193,11 @@ def processing_requests_{route_code_list_len}(**args):
     return resp
     """
 
-        self.route_code_list.append(route_code)
+        self.__route_code_list.append(route_code)
 
     #立刻启动模拟服务
     def start_mock_server(self):
-        route_code_string = "\n".join(self.route_code_list)
+        route_code_string = "\n".join(self.__route_code_list)
         flask_code = f"""
 from flask import request,app,Flask,make_response,jsonify
 import logging
@@ -210,20 +217,20 @@ def clear_mock_server_request_data():
     all_request_data_list.clear()
 
 if __name__=="__main__":
-        app.run(host='0.0.0.0',port={self.mock_server_port})
+        app.run(host='0.0.0.0',port={self.__mock_server_port})
         """
         with open("mock_server_code.py","w") as fp:
             fp.write(flask_code)
 
-        self.system_operation.start_mock_server(self.mock_server_port)
+        self.__system_operation.start_mock_server(self.__mock_server_port)
         sleep(4)
 
     #此函数用于,启动模拟服务之前,先把特定端口号的进程kill调
     def stop_port_process(self):
-        self.system_operation.stop_port_process(self.mock_server_port)
+        self.__system_operation.stop_port_process(self.mock_server_port)
 
     def stop_mock_server(self):
-        self.system_operation.stop_mock_server()
+        self.__system_operation.stop_mock_server()
 
     #返回 模拟服务接收到的请求日志
     def get_mock_server_request_data_list(self):
@@ -247,7 +254,7 @@ if __name__=="__main__":
 
         mock_server_request_data_list = []
 
-        mock_server_request_data_json = requests.get(self.query_request_data_interface_url).json()
+        mock_server_request_data_json = requests.get(self.__query_request_data_interface_url).json()
         for request_data in  mock_server_request_data_json:
             mock_server_request_data = MockServerRequestData(request_data)
             mock_server_request_data_list.append(mock_server_request_data)
@@ -255,12 +262,12 @@ if __name__=="__main__":
 
     @property
     def mock_server_request_data_len(self):
-        mock_server_request_data_json = requests.get(self.query_request_data_interface_url).json()
+        mock_server_request_data_json = requests.get(self.__query_request_data_interface_url).json()
         return len(mock_server_request_data_json)
 
 
     def clear_mock_server_request_data(self):
-        requests.get(self.clear_request_data_interface_url)
+        requests.get(self.__clear_request_data_interface_url)
 
 
 
